@@ -128,6 +128,7 @@ $(function () {
         self.api_allowCrossOrigin = ko.observable(undefined);
 
         self.apiKeyVisible = ko.observable(false);
+        self.revealingApiKey = ko.observable(false);
 
         self.appearance_name = ko.observable(undefined);
         self.appearance_color = ko.observable(undefined);
@@ -151,6 +152,7 @@ $(function () {
         self.webcam_ffmpegThreads = ko.observable(undefined);
         self.webcam_ffmpegVideoCodec = ko.observable(undefined);
         self.webcam_watermark = ko.observable(undefined);
+        self.webcam_renderAfterPrintDelay = ko.observable(undefined);
         self.webcam_defaultWebcam = ko.observable(undefined);
         self.webcam_snapshotWebcam = ko.observable(undefined);
         self.webcam_webcams = ko.observableArray([]);
@@ -164,6 +166,7 @@ $(function () {
         self.feature_printStartConfirmation = ko.observable(undefined);
         self.feature_printCancelConfirmation = ko.observable(undefined);
         self.feature_uploadOverwriteConfirmation = ko.observable(undefined);
+        self.feature_fileDeleteConfirmation = ko.observable(undefined);
         self.feature_g90InfluencesExtruder = ko.observable(undefined);
         self.feature_autoUppercaseBlacklist = ko.observable(undefined);
         self.feature_enableDragDropUpload = ko.observable(undefined);
@@ -689,17 +692,19 @@ $(function () {
             self.settingsDialog.modal("hide");
         };
 
-        self.generateApiKey = function () {
+        self.generateApiKey = () => {
             if (!CONFIG_ACCESS_CONTROL) return;
 
             showConfirmationDialog(
                 gettext(
                     "This will generate a new API Key. The old API Key will cease to function immediately."
                 ),
-                function () {
-                    OctoPrint.settings.generateApiKey().done(function (response) {
-                        self.api_key(response.apikey);
-                        self.requestData();
+                () => {
+                    self.loginState.reauthenticateIfNecessary(() => {
+                        OctoPrint.settings.generateApiKey().done((response) => {
+                            self.api_key(response.apikey);
+                            self.requestData();
+                        });
                     });
                 }
             );
@@ -713,9 +718,11 @@ $(function () {
                 gettext(
                     "This will delete the API Key. It will cease to to function immediately."
                 ),
-                function () {
-                    OctoPrint.settings.deleteApiKey().done(() => {
-                        self.api_key(undefined);
+                () => {
+                    self.loginState.reauthenticateIfNecessary(() => {
+                        OctoPrint.settings.deleteApiKey().done(() => {
+                            self.api_key(undefined);
+                        });
                     });
                 }
             );
@@ -725,7 +732,6 @@ $(function () {
             copyToClipboard(self.api_key());
         };
 
-        self.revealingApiKey = ko.observable(false);
         self.revealApiKey = () => {
             self.loginState.reauthenticateIfNecessary(() => {
                 self.revealingApiKey(true);
@@ -1095,7 +1101,6 @@ $(function () {
             return data;
         };
 
-        self.reauthenticationTimeout = undefined;
         self.fromResponse = function (response, local) {
             // server side changes to set
             var serverChangedData;
@@ -1284,14 +1289,8 @@ $(function () {
 
             firstRequest.resolve();
 
-            // special delivery for the API key flag
-            self.apiKeyVisible(self.loginState.checkCredentialsSeen());
-            if (self.apiKeyVisible()) {
-                self.reauthenticationTimeout =
-                    self.loginState.afterReauthenticationTimeout(() => {
-                        self.requestData();
-                    }, self.reauthenticationTimeout);
-            }
+            // this should only ever return true if we triggered the request through the "reveal api key" button
+            self.apiKeyVisible(self.revealingApiKey());
 
             // if autologinLocal is enabled and the heads-up not yet acknowledged, show it now
             if (
@@ -1494,6 +1493,11 @@ $(function () {
                     self.requestData();
                 };
 
+        self.onUserCredentialsOutdated = () => {
+            self.apiKeyVisible(false);
+            self.requestData();
+        };
+
         self.validURL = function (str) {
             var pattern = new RegExp(
                 "^(https?:\\/\\/)?" + // protocol
